pub struct JwtConfig {
pub access_ttl: Duration,
pub refresh_ttl: Duration,
/* private fields */
}Expand description
Configuration for JWT signing and validation.
Fields
access_ttl: DurationAccess token lifetime.
refresh_ttl: DurationRefresh token lifetime.
Implementations
Sourceimpl JwtConfig
impl JwtConfig
Sourcepub fn new(secret: &str, access_ttl_secs: i64, refresh_ttl_secs: i64) -> Self
pub fn new(secret: &str, access_ttl_secs: i64, refresh_ttl_secs: i64) -> Self
Creates a new JwtConfig from a secret string.
access_ttl_secs — lifetime for access tokens in seconds.
refresh_ttl_secs — lifetime for refresh tokens in seconds.
Sourcepub fn from_env() -> Option<Self>
pub fn from_env() -> Option<Self>
Creates a JwtConfig from the JWT_SECRET environment variable.
Returns None if the variable is not set or is empty.
Sourcepub fn encode_access(&self, user_id: &str, role: &str) -> Result<String, Error>
pub fn encode_access(&self, user_id: &str, role: &str) -> Result<String, Error>
Encodes an access token for the given user ID and role.