pub fn create_redis_pool(redis_url: &str) -> Result<Pool, ShaperailError>Expand description
Creates a Redis connection pool from the given URL.
The URL should be in the format redis://host:port/db.
pub fn create_redis_pool(redis_url: &str) -> Result<Pool, ShaperailError>Creates a Redis connection pool from the given URL.
The URL should be in the format redis://host:port/db.