pub struct UploadHandler { /* private fields */ }Expand description
Handles file uploads with validation, storage, and optional image processing.
Implementations
Sourceimpl UploadHandler
impl UploadHandler
Sourcepub fn new(backend: Arc<StorageBackend>) -> Self
pub fn new(backend: Arc<StorageBackend>) -> Self
Create a new upload handler with the given storage backend.
Sourcepub async fn process_upload(
&self,
filename: &str,
data: &[u8],
mime_type: &str,
max_size: Option<u64>,
allowed_types: Option<&[String]>,
storage_prefix: &str,
) -> Result<FileMetadata, StorageError>
pub async fn process_upload( &self, filename: &str, data: &[u8], mime_type: &str, max_size: Option<u64>, allowed_types: Option<&[String]>, storage_prefix: &str, ) -> Result<FileMetadata, StorageError>
Process an upload: validate size and MIME type, store the file.
Returns the file metadata on success.
Sourcepub async fn create_thumbnail(
&self,
original_path: &str,
max_width: u32,
max_height: u32,
storage_prefix: &str,
) -> Result<FileMetadata, StorageError>
pub async fn create_thumbnail( &self, original_path: &str, max_width: u32, max_height: u32, storage_prefix: &str, ) -> Result<FileMetadata, StorageError>
Generate a thumbnail for an image file.
Returns the metadata of the stored thumbnail.
Sourcepub async fn resize_image(
&self,
original_path: &str,
width: u32,
height: u32,
storage_prefix: &str,
) -> Result<FileMetadata, StorageError>
pub async fn resize_image( &self, original_path: &str, width: u32, height: u32, storage_prefix: &str, ) -> Result<FileMetadata, StorageError>
Resize an image to fit within the given dimensions.
Sourcepub async fn signed_url(
&self,
path: &str,
expires_secs: u64,
) -> Result<String, StorageError>
pub async fn signed_url( &self, path: &str, expires_secs: u64, ) -> Result<String, StorageError>
Generate a time-limited signed URL for a file.
Sourcepub async fn delete(&self, path: &str) -> Result<(), StorageError>
pub async fn delete(&self, path: &str) -> Result<(), StorageError>
Delete a file from storage (used for orphan cleanup).
Sourcepub fn backend(&self) -> &StorageBackend
pub fn backend(&self) -> &StorageBackend
Returns a reference to the underlying storage backend.